==> apache-camel-quarkus-2.13.3-src.zip: camel-quarkus-2.13.3/integration-tests/bean-validator/src/main/java/org/apache/camel/quarkus/component/bean/validator/it/ValidatorFactoryCustomizer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.bean.validator.it;

import java.util.Locale;

import javax.enterprise.context.ApplicationScoped;
import javax.enterprise.inject.Produces;
import javax.inject.Singleton;
import javax.validation.MessageInterpolator;

@ApplicationScoped
public class ValidatorFactoryCustomizer {

    @Produces
    @Singleton
    public MyMessageInterpolator createMyMessageInterpolator() {
        return new MyMessageInterpolator();
    }

    class MyMessageInterpolator implements MessageInterpolator {

        private int count = 0;

        @Override
        public String interpolate(String messageTemplate, Context context) {
            count++;
            return null;
        }

        @Override
        public String interpolate(String messageTemplate, Context context, Locale locale) {
            count++;
            return null;
        }

        public int getCount() {
            return count;
        }
    }
}

==> apache-camel-quarkus-3.20.3-src.zip: camel-quarkus-3.20.3/integration-tests/bean-validator/src/main/java/org/apache/camel/quarkus/component/bean/validator/it/ValidatorFactoryCustomizer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.bean.validator.it;

import java.util.Locale;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.enterprise.inject.Produces;
import jakarta.inject.Singleton;
import jakarta.validation.MessageInterpolator;

@ApplicationScoped
public class ValidatorFactoryCustomizer {

    @Produces
    @Singleton
    public MyMessageInterpolator createMyMessageInterpolator() {
        return new MyMessageInterpolator();
    }

    class MyMessageInterpolator implements MessageInterpolator {

        private int count = 0;

        @Override
        public String interpolate(String messageTemplate, Context context) {
            count++;
            return null;
        }

        @Override
        public String interpolate(String messageTemplate, Context context, Locale locale) {
            count++;
            return null;
        }

        public int getCount() {
            return count;
        }
    }
}
